@@ -2,8 +2,7 @@
 
 class RatioData:
     def __init__(self):
-        self.legend = 2
-        self.price = 18
+        self.price = 5
         self.volume = 5
 
 RATIO = RatioData()
@@ -19,7 +18,7 @@ WATERMARK = WatermarkData()
 class AdjustData:
     def __init__(self):
         # 여백
-        self.top = 0.95
+        self.top = 0.98
         self.bottom = 0.05
         self.left = 0.01
         self.right = 0.93
@@ -31,7 +30,7 @@ ADJUST = AdjustData()
 
 class FigureData:
     def __init__(self):
-        self.facecolor: str|tuple[float, float, float, float] = 'w'
+        self.facecolor: str|tuple[float, float, float, float] = '#fafafa'
         self.figsize = (14, 7)
         self.RATIO = RATIO
         self.ADJUST = ADJUST
