@@ -3,11 +3,10 @@ from .. import figure
 
 class RatioData:
     def __init__(self):
-        self.legend = 2
-        self.price = 18
-        self.volume = 5
-        self.slider = 3
+        self.price = 9
+        self.volume = 3
         self.none = 2
+        self.slider = 1.5
 
 RATIO = RatioData()
 
